<?php

namespace Controllers;

use Traits\TResponse;
use Exception\CustomException;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class Settings extends Simple {
    use TResponse;
    
    /** @var \Services\Settings */
    private $settingService;
    /** @var \Services\Password $passwordService */
    protected $passwordService;

    public function __construct(\Services\Settings $settingService, \Services\Password $passwordService) {
        $this->settingService  = $settingService;
        $this->passwordService = $passwordService;
    }

    /**
     * @param Request $request
     * @param Response $response
     */
    public function findADConfiguration(Request $request, Response $response) {
        try {
            $adConfig = $this->settingService->findADConfigurationByNrOrg();
            $this->sendResponse($adConfig, 200);
        } catch(CustomException $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function saveADConfiguration(Request $request, Response $response) {
        try {
            $params      = $request->getParameters();
            $useAd       = $params['USE_AD'];
            $domain      = $params['DOMAIN'];
            $server      = $params['SERVER'];
            $admUser     = isset($params['ADM_USER']) ? $params['ADM_USER'] : null;
            $admPassword = isset($params['ADM_PASSWORD']) ? $params['ADM_PASSWORD'] : null;
            $adConfig    = $this->settingService->saveADConfiguration($domain, $server, $admUser, $admPassword, $useAd);
            $this->sendResponse($adConfig, 200);
        } catch(CustomException $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function getOrganizationParameters(Request $request, Response $response) {
        try {
            $generalParameters  = $this->settingService->getOrganizationParameters();
            $generalParameters  = empty($generalParameters) ? array() : $generalParameters[0];
            $passwordParameters = $this->passwordService->findPasswordParameters();
            $passwordParameters = empty($passwordParameters) ? array() : $passwordParameters[0];
            $parameters = array_merge($generalParameters, $passwordParameters);
            $this->sendResponse($parameters, 200);
        } catch(CustomException $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function saveOrganizationParameters(Request $request, Response $response){
        try {
            $row = $request->getParameters();
            $useRestriction = $row['USE_RESTRICTION'];
            $idUtCtrlSen    = $row['IDUTCTRLSEN'];
            $nrDiasExpSen   = $row['NRDIASEXPSEN'];
            $nrDiasAviso    = $row['NRDIASAVISO'];
            $nrAltSenhRep   = $row['NRALTSENHREP'];
            $cdPictSenha    = $row['CDPICTSENHA'];
            $nrErroSenha    = $row['NRERROSENHA'];
            $this->settingService->saveOrganizationParameters($useRestriction, $idUtCtrlSen, $nrDiasExpSen,
                $nrDiasAviso, $nrAltSenhRep, $cdPictSenha, $nrErroSenha);
        } catch(CustomException $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getOrganizationRestrictionByIp(Request $request, Response $response){
        try {
            $restrictions = $this->settingService->getOrganizationRestrictionByIp();
            $this->sendResponse($restrictions, 200);
        } catch(\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function saveOrganizationRestrictionByIp(Request $request, Response $response){
        try {
            $row = $request->getParameters();
            $ipv4 = isset($row['IPV4']) ? $row['IPV4'] : null;
            $ipv6 = isset($row['IPV6']) ? $row['IPV6'] : null;
            $ipRestrictedId = isset($row['ID']) ? $row['ID'] : null;
            $active = isset($row['ACTIVE']) ? $row['ACTIVE'] : null;
            $description = isset($row['DESCRIPTION']) ? $row['DESCRIPTION'] : null;
            $restrictionArrayId = $this->settingService->saveOrganizationRestrictionByIp($ipRestrictedId, $ipv4, $ipv6, $description, $active);
            $this->sendResponse($restrictionArrayId, 200);
        } catch(CustomException $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function removeOrganizationRestrictionByIp(Request $request, Response $response){
        try {
            $restrictionId = $request->getParameters();
            $this->settingService->removeOrganizationRestrictionByIp($restrictionId);
        } catch(CustomException $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
} 